@@ -219,10 +219,22 @@ def view_invoices(timesheet: model.Timesheet):
     month_last_day = datetime.datetime(today.year, today.month, days_in_this_month)
     month_middle = datetime.datetime(today.year, today.month, 15)
     submittal_due_date = month_middle if today < month_middle else month_last_day
+
+    _logger.debug(f"{submittal_due_date=}")
+    _logger.debug(f"{month_middle=}")
+    _logger.debug(f"{month_last_day=}")
+    _logger.debug(f"{datetime.datetime.now().date()=}")
+
+    if datetime.datetime.now().date() == month_middle.date():
+        submittal_due_date = datetime.datetime.now()
+
     submittal_due_from_now_delta = (
         submittal_due_date - today + datetime.timedelta(days=1)
     )
 
+    if datetime.datetime.now().date() == month_middle.date():
+        submittal_due_date = datetime.datetime.now() + submittal_due_from_now_delta
+
     display_dicts = []
     for invoice in invoices_by_inv_number:
         if invoice.submitted_on is None:
